@@ -1,7 +1,3 @@
-#
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
 # SPDX-FileCopyrightText: 2004-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
@@ -41,6 +37,7 @@ short_description = _('Computer: IP client')
 object_name = _('IP client')
 object_name_plural = _('IP clients')
 long_description = ''
+# fmt: off
 options = {
     'pki': pki_option(),
 }
@@ -170,6 +167,7 @@ mapping.register('mac', 'macAddress', encoding='ASCII')
 mapping.register('network', 'univentionNetworkLink', None, univention.admin.mapping.ListToString)
 mapping.register('domain', 'associatedDomain', None, univention.admin.mapping.ListToString, encoding='ASCII')
 register_pki_mapping(mapping)
+# fmt: on
 
 # add Nagios extension
 nagios.addPropertiesMappingOptionsAndLayout(property_descriptions, mapping, options, layout)
@@ -242,14 +240,27 @@ def rewrite(filter: univention.admin.filter.expression, mapping: univention.admi
         univention.admin.mapping.mapRewrite(filter, mapping)
 
 
-def lookup(co: None, lo: univention.admin.uldap.access, filter_s: str, base: str = '', superordinate: univention.admin.handlers.simpleLdap | None = None, scope: str = 'sub', unique: bool = False, required: bool = False, timeout: int = -1, sizelimit: int = 0, serverctrls: list[ldap.controls.LDAPControl] | None = None, response: dict | None = None) -> list[univention.admin.handlers.simpleLdap]:
+def lookup(
+    co: None,
+    lo: univention.admin.uldap.access,
+    filter_s: str,
+    base: str = '',
+    superordinate: univention.admin.handlers.simpleLdap | None = None,
+    scope: str = 'sub',
+    unique: bool = False,
+    required: bool = False,
+    timeout: int = -1,
+    sizelimit: int = 0,
+    serverctrls: list[ldap.controls.LDAPControl] | None = None,
+    response: dict | None = None,
+) -> list[univention.admin.handlers.simpleLdap]:
     filter_s = univention.admin.filter.replace_fqdn_filter(filter_s)
     filter_s = univention.admin.handlers.dns.alias.lookup_alias_filter(lo, filter_s)
     filter = univention.admin.filter.conjunction('&', [
         univention.admin.filter.expression('objectClass', 'univentionHost'),
         univention.admin.filter.expression('objectClass', 'univentionClient'),
         univention.admin.filter.conjunction('!', [univention.admin.filter.expression('objectClass', 'posixAccount')]),
-    ])
+    ])  # fmt: skip
 
     if filter_s:
         filter_p = univention.admin.filter.parse(filter_s)
