@@ -1,7 +1,3 @@
-#
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
 # SPDX-FileCopyrightText: 2004-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
@@ -36,6 +32,7 @@ short_description = _('Computer: Domain trust account')
 object_name = _('Domain trust account')
 object_name_plural = _('Domain trust accounts')
 long_description = ''
+# fmt: off
 options = {
     'pki': pki_option(),
 }
@@ -82,6 +79,7 @@ mapping.register('name', 'cn', None, univention.admin.mapping.ListToString)
 mapping.register('description', 'description', None, univention.admin.mapping.ListToString)
 register_pki_mapping(mapping)
 register_role_mapping(mapping)
+# fmt: on
 
 
 class object(univention.admin.handlers.simpleLdap, PKIIntegration):
@@ -146,7 +144,7 @@ class object(univention.admin.handlers.simpleLdap, PKIIntegration):
         ml = super()._ldap_modlist()
 
         if self.hasChanged('name') and self['name']:
-            requested_uid = "%s$" % self['name']
+            requested_uid = '%s$' % self['name']
             try:
                 ml.append(('uid', self.oldattr.get('uid', []), [self.request_lock('uid', requested_uid).encode('UTF-8')]))
             except univention.admin.uexceptions.noLock:
@@ -171,7 +169,7 @@ def lookup(co, lo, filter_s, base='', superordinate=None, scope='sub', unique=Fa
     filter = univention.admin.filter.conjunction('&', [
         univention.admin.filter.expression('objectClass', 'sambaSamAccount'),
         univention.admin.filter.expression('sambaAcctFlags', '[I          ]'),
-    ])
+    ])  # fmt: skip
 
     if filter_s:
         filter_p = univention.admin.filter.parse(filter_s)
