@@ -1,7 +1,3 @@
-#
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
 # SPDX-FileCopyrightText: 2004-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
@@ -30,6 +26,7 @@ short_description = _('Container: Domain')
 object_name = _('Domain Container')
 object_name_plural = _('Domain Containers')
 long_description = ''
+# fmt: off
 options = {
     'default': univention.admin.option(
         short_description=short_description,
@@ -208,6 +205,7 @@ mapping.register('defaultDomainControllerMBGroup', 'univentionDefaultDomainContr
 mapping.register('defaultDomainControllerGroup', 'univentionDefaultDomainControllerGroup', None, univention.admin.mapping.ListToString)
 mapping.register('defaultMemberServerGroup', 'univentionDefaultMemberserverGroup', None, univention.admin.mapping.ListToString)
 mapping.register('defaultClientGroup', 'univentionDefaultClientGroup', None, univention.admin.mapping.ListToString)
+# fmt: on
 
 
 class object(univention.admin.handlers.simpleLdap):
@@ -223,15 +221,19 @@ class object(univention.admin.handlers.simpleLdap):
         univention.admin.handlers.simpleLdap.open(self)
 
         if self.exists():
-            self['dnsForwardZone'] = self.lo.authz_connection.searchDn(base=self.dn, scope='domain', filter='(&(objectClass=dNSZone)(sOARecord=*)(!(zoneName=*.in-addr.arpa))(!(zoneName=*.ip6.arpa)))')
-            self['dnsReverseZone'] = self.lo.authz_connection.searchDn(base=self.dn, scope='domain', filter='(&(objectClass=dNSZone)(sOARecord=*)(|(zoneName=*.in-addr.arpa)(zoneName=*.ip6.arpa)))')
+            self['dnsForwardZone'] = self.lo.authz_connection.searchDn(
+                base=self.dn, scope='domain', filter='(&(objectClass=dNSZone)(sOARecord=*)(!(zoneName=*.in-addr.arpa))(!(zoneName=*.ip6.arpa)))',
+            )
+            self['dnsReverseZone'] = self.lo.authz_connection.searchDn(
+                base=self.dn, scope='domain', filter='(&(objectClass=dNSZone)(sOARecord=*)(|(zoneName=*.in-addr.arpa)(zoneName=*.ip6.arpa)))',
+            )
             self.save()
 
     @classmethod
     def unmapped_lookup_filter(cls):
         return univention.admin.filter.conjunction('&', [
             univention.admin.filter.expression('objectClass', 'univentionBase'),
-        ])
+        ])  # fmt: skip
 
 
 lookup = object.lookup
