@@ -1,7 +1,3 @@
-#
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
 # SPDX-FileCopyrightText: 2004-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
@@ -29,6 +25,7 @@ short_description = _('Container: Organisational Unit')
 object_name = _('Organisational Unit')
 object_name_plural = _('Organisational Units')
 long_description = ''
+# fmt: off
 options = {
     'default': univention.admin.option(
         short_description=short_description,
@@ -217,6 +214,7 @@ mapping.register('defaultDomainControllerMBGroup', 'univentionDefaultDomainContr
 mapping.register('defaultDomainControllerGroup', 'univentionDefaultDomainControllerGroup', None, univention.admin.mapping.ListToString)
 mapping.register('defaultMemberServerGroup', 'univentionDefaultMemberserverGroup', None, univention.admin.mapping.ListToString)
 mapping.register('defaultClientGroup', 'univentionDefaultClientGroup', None, univention.admin.mapping.ListToString)
+# fmt: on
 
 
 class object(univention.admin.handlers.simpleLdap):
@@ -266,7 +264,7 @@ class object(univention.admin.handlers.simpleLdap):
         changes = []
 
         dn_bytes = self.dn.encode('UTF-8')
-        for (prop, attr) in self.PATH_KEYS.items():
+        for prop, attr in self.PATH_KEYS.items():
             if self.oldinfo.get(prop) != self.info.get(prop):
                 entries = self.lo.authz_connection.getAttr(self.default_dn, attr)
                 if self.info[prop] == '0':
@@ -325,7 +323,7 @@ class object(univention.admin.handlers.simpleLdap):
         return univention.admin.filter.conjunction('&', [
             univention.admin.filter.expression('objectClass', 'organizationalUnit'),
             univention.admin.filter.conjunction('!', [univention.admin.filter.expression('objectClass', 'univentionBase')]),
-        ])
+        ])  # fmt: skip
 
 
 lookup = object.lookup
