@@ -1,7 +1,3 @@
-#
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
 # SPDX-FileCopyrightText: 2004-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
@@ -32,6 +28,7 @@ short_description = _('DNS: Host Record')
 object_name = _('Host record')
 object_name_plural = _('Host records')
 long_description = _('Resolve the symbolic name to IP addresses.')
+# fmt: off
 options = {
     'default': univention.admin.option(
         short_description=short_description,
@@ -122,6 +119,7 @@ mapping.register('mx', 'mXRecord', mapMX, unmapMX, encoding='ASCII')
 mapping.register('txt', 'tXTRecord', encoding='ASCII')
 mapping.register('zonettl', 'dNSTTL', univention.admin.mapping.mapUNIX_TimeInterval, univention.admin.mapping.unmapUNIX_TimeInterval)
 mapping.registerUnmapping('a', unmapIPAddresses, encoding='ASCII')
+# fmt: on
 
 
 class object(DNSBase):
@@ -168,7 +166,7 @@ class object(DNSBase):
                 univention.admin.filter.expression('mXRecord', '*', escape=False),
                 univention.admin.filter.expression('univentionObjectType', module, escape=True),  # host record without any record
             ]),
-        ])
+        ])  # fmt: skip
 
     @classmethod
     def rewrite_filter(cls, filter: univention.admin.filter.expression, mapping: univention.admin.mapping.mapping) -> None:
@@ -176,7 +174,7 @@ class object(DNSBase):
             filter.transform_to_conjunction(univention.admin.filter.conjunction('|', [
                 univention.admin.filter.expression('aRecord', filter.value, escape=False),
                 univention.admin.filter.expression('aAAARecord', filter.value, escape=False),
-            ]))
+            ]))  # fmt: skip
         else:
             return super().rewrite_filter(filter, mapping)
 
@@ -190,5 +188,5 @@ def identify(dn: str, attr: univention.admin.handlers._Attributes, canonical: bo
         is_dns(attr)
         and not is_zone(attr)
         and is_not_handled_by_other_module_than(attr, module)
-        and (has_any(attr, 'aRecord', 'aAAARecord', 'mXRecord') or attr.get("univentionObjectType")),
+        and (has_any(attr, 'aRecord', 'aAAARecord', 'mXRecord') or attr.get('univentionObjectType')),
     )
