@@ -1,7 +1,3 @@
-#
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
 # SPDX-FileCopyrightText: 2004-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
@@ -35,6 +31,7 @@ short_description = _('DNS: Reverse lookup zone')
 object_name = _('Reverse lookup zone')
 object_name_plural = _('Reverse lookup zones')
 long_description = _('Map IP addresses back to hostnames.')
+# fmt: off
 options = {
     'default': univention.admin.option(
         short_description=short_description,
@@ -128,6 +125,7 @@ layout = [
         ]),
     ]),
 ]
+# fmt: on
 
 
 def mapSubnet(subnet, encoding=()):
@@ -173,10 +171,12 @@ def unmapSubnet(zone, encoding=()):
         raise ValueError('Neither an IPv4 nor an IPv6 reverse address')
 
 
+# fmt: off
 mapping = univention.admin.mapping.mapping()
 mapping.register('subnet', 'zoneName', mapSubnet, unmapSubnet, encoding='ASCII')
 mapping.register('zonettl', 'dNSTTL', univention.admin.mapping.mapUNIX_TimeInterval, univention.admin.mapping.unmapUNIX_TimeInterval)
 mapping.register('nameserver', 'nSRecord', encoding='ASCII')
+# fmt: on
 
 
 class object(univention.admin.handlers.simpleLdap):
@@ -221,7 +221,15 @@ class object(univention.admin.handlers.simpleLdap):
             retry = univention.admin.mapping.mapUNIX_TimeInterval(self['retry'])
             expire = univention.admin.mapping.mapUNIX_TimeInterval(self['expire'])
             ttl = univention.admin.mapping.mapUNIX_TimeInterval(self['ttl'])
-            soa = b'%s %s %s %s %s %s %s' % (self['nameserver'][0].encode('ASCII'), escapeSOAemail(self['contact']).encode('ASCII'), self['serial'].encode('ASCII'), refresh, retry, expire, ttl)
+            soa = b'%s %s %s %s %s %s %s' % (
+                self['nameserver'][0].encode('ASCII'),
+                escapeSOAemail(self['contact']).encode('ASCII'),
+                self['serial'].encode('ASCII'),
+                refresh,
+                retry,
+                expire,
+                ttl,
+            )
             ml.append(('sOARecord', self.oldattr.get('sOARecord', []), soa))
         return ml
 
@@ -251,7 +259,7 @@ class object(univention.admin.handlers.simpleLdap):
                 univention.admin.filter.expression('zoneName', '*%s' % ARPA_IP4, escape=False),
                 univention.admin.filter.expression('zoneName', '*%s' % ARPA_IP6, escape=False),
             ]),
-        ])
+        ])  # fmt: skip
 
 
 lookup = object.lookup
@@ -260,7 +268,5 @@ lookup_filter = object.lookup_filter
 
 def identify(dn: str, attr: univention.admin.handlers._Attributes) -> bool:
     return bool(
-        is_zone(attr)
-        and is_dns(attr)
-        and is_reverse_zone(attr),
+        is_zone(attr) and is_dns(attr) and is_reverse_zone(attr),
     )
