@@ -7,7 +7,6 @@ from __future__ import annotations
 
 import copy
 import time
-from logging import getLogger
 
 import ldap
 from ldap.filter import filter_format
@@ -24,8 +23,6 @@ from univention.admin.layout import Group, Tab
 from univention.dn import DN
 
 
-log = getLogger('ADMIN')
-
 translation = univention.admin.localization.translation('univention.admin.handlers.groups')
 _ = translation.translate
 
@@ -347,7 +344,7 @@ class object(univention.admin.handlers.simpleLdap):
                             raise RuntimeError('%s not detected: %r' % (i, result))
 
             time_end = time.time()
-            log.debug('groups/group: open(): member check duration: %1.2fs', time_end - time_start)
+            self.log.debug('groups/group: open(): member check duration: %1.2fs', time_end - time_start)
 
             self.save()
 
@@ -516,7 +513,7 @@ class object(univention.admin.handlers.simpleLdap):
                         if uid_list:
                             result.append(uid_list[0].decode('UTF-8'))
                             if len(uid_list) > 1:
-                                log.warning('groups/group: A groupmember has multiple UIDs (%s %r)', uniqueMember, uid_list)
+                                self.log.warning('A groupmember has multiple UIDs', dn=uniqueMember, uid=uid_list)
                 return result
 
             # calling keepCase is not necessary as the LDAP server already handles the case when removing elements
@@ -547,7 +544,7 @@ class object(univention.admin.handlers.simpleLdap):
                 memberUidAdd = [x.encode('UTF-8') for x in memberUidAdd]
                 ml.append(('memberUid', '', memberUidAdd))
 
-            log.debug('groups/group: _ldap_modlist(): %.3fs', time.time() - t1)
+            self.log.debug('groups/group: _ldap_modlist(): %.3fs', time.time() - t1)
 
         return ml
 
@@ -606,7 +603,7 @@ class object(univention.admin.handlers.simpleLdap):
                 continue
             newmembers = copy.deepcopy(members)
             newmembers = self.__case_insensitive_remove_from_list(self.dn, newmembers)
-            log.debug('groups/group: remove from supergroup %s', group)
+            self.log.debug('remove from supergroup', group=group, dn=self.dn)
             self.__set_membership_attributes(group, members, newmembers)
 
     def _ldap_post_move(self, olddn: str) -> None:
@@ -628,7 +625,7 @@ class object(univention.admin.handlers.simpleLdap):
             newmembers = copy.deepcopy(members)
             newmembers = self.__case_insensitive_remove_from_list(olddn, newmembers)
             newmembers.append(self.dn)
-            log.debug('groups/group: updating supergroup %s', group)
+            self.log.debug('updating supergroup', group=group, dn=self.dn)
             self.__set_membership_attributes(group, members, newmembers)
 
     def __update_membership(self) -> None:
@@ -643,7 +640,7 @@ class object(univention.admin.handlers.simpleLdap):
 
         # rewrite membership attributes in "supergroup" if we have a new name (rename)
         if old_name and old_name != new_name:
-            log.debug('groups/group: rewrite memberuid after rename')
+            self.log.debug('groups/group: rewrite memberuid after rename')
             for group in self.info.get('memberOf', []):
                 if isinstance(group, list):
                     group = group[0]
@@ -672,7 +669,7 @@ class object(univention.admin.handlers.simpleLdap):
                 continue
             newmembers = copy.deepcopy(members)
             newmembers.append(self.dn)
-            log.debug('groups/group: add to supergroup %s', group)
+            self.log.debug('add to supergroup', group=group, dn=self.dn)
             self.__set_membership_attributes(group, members, newmembers)
 
         for group in remove_from_group:
@@ -685,7 +682,7 @@ class object(univention.admin.handlers.simpleLdap):
             if self.__case_insensitive_in_list(self.old_dn, newmembers):
                 newmembers = self.__case_insensitive_remove_from_list(self.old_dn, newmembers)
             if members != newmembers:
-                log.debug('groups/group: remove from supergroup %s', group)
+                self.log.debug('remove from supergroup', group=group, dn=self.dn)
                 self.__set_membership_attributes(group, members, newmembers)
 
     def __set_membership_attributes(self, group, members, newmembers):
@@ -828,8 +825,7 @@ class object(univention.admin.handlers.simpleLdap):
         old_groupType = self.oldinfo.get('adGroupType', 0)
         new_groupType = self.info.get('adGroupType', 0)
 
-        log.debug('groups/group: old_groupType: %s', old_groupType)
-        log.debug('groups/group: new_groupType: %s', new_groupType)
+        self.log.debug('Changing groupType', old=old_groupType, new=new_groupType)
 
         if not old_groupType or not new_groupType:
             return
@@ -882,7 +878,7 @@ class object(univention.admin.handlers.simpleLdap):
     def __generate_group_sid(self, gidNum):
         new_groupType = self.info.get('adGroupType', 0)
 
-        log.debug('groups/group: new_groupType: %s', new_groupType)
+        self.log.debug('Setting groupType', value=new_groupType)
         if self['sambaRID']:
             return self.__allocate_rid(self['sambaRID'])
         elif self.s4connector_present and not self.__is_groupType_local(new_groupType):
