@@ -1,7 +1,3 @@
-#
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
 # SPDX-FileCopyrightText: 2004-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
@@ -34,8 +30,8 @@ module = 'policies/memberpackages'
 operations = ['add', 'edit', 'remove', 'search']
 
 policy_oc = 'univentionPolicyPackagesMember'
-policy_apply_to = ["computers/memberserver"]
-policy_position_dn_prefix = "cn=packages,cn=update"
+policy_apply_to = ['computers/memberserver']
+policy_position_dn_prefix = 'cn=packages,cn=update'
 
 childs = False
 short_description = _('Policy: Packages for Managed Nodes')
@@ -43,6 +39,7 @@ object_name = _('Managed Node packages policy')
 object_name_plural = _('Managed Node packages policies')
 policy_short_description = _('Packages for Managed Nodes')
 long_description = ''
+# fmt: off
 options = {
     'default': univention.admin.option(
         short_description=short_description,
@@ -97,6 +94,7 @@ mapping.register('name', 'cn', None, univention.admin.mapping.ListToString)
 mapping.register('memberPackages', 'univentionMemberPackages')
 mapping.register('memberPackagesRemove', 'univentionMemberPackagesRemove')
 register_policy_mapping(mapping)
+# fmt: on
 
 
 class object(univention.admin.handlers.simplePolicy):
