@@ -1,7 +1,3 @@
-#
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
 # SPDX-FileCopyrightText: 2004-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
@@ -23,18 +19,17 @@ def logonToChangePWMap(udm_value):
     'User must logon to change PW' behaves like an integer (at least
     to us), but must be stored as either 0 (allow) or 2 (disallow)
     """
-    if (udm_value == "1"):
-        return b"2"
+    if udm_value == '1':
+        return b'2'
     else:
-        return b"0"
+        return b'0'
 
 
 def logonToChangePWUnmap(ldap_value):
-
-    if (ldap_value[0] == b"2"):
-        return "1"
+    if ldap_value[0] == b'2':
+        return '1'
     else:
-        return "2"
+        return '2'
 
 
 module = 'settings/sambaconfig'
@@ -45,6 +40,7 @@ short_description = _('Settings: Samba Configuration')
 object_name = _('Samba Configuration')
 object_name_plural = _('Samba Configuration settings')
 long_description = ''
+# fmt: off
 options = {
     'default': univention.admin.option(
         short_description=short_description,
@@ -139,6 +135,7 @@ mapping.register('lockoutDuration', 'univentionSambaLockoutDuration', univention
 mapping.register('resetCountMinutes', 'univentionSambaResetCountMinutes', None, univention.admin.mapping.ListToString)
 mapping.register('disconnectTime', 'univentionSambaDisconnectTime', univention.admin.mapping.mapUNIX_TimeInterval, univention.admin.mapping.unmapUNIX_TimeInterval)
 mapping.register('refuseMachinePWChange', 'univentionSambaRefuseMachinePWChange', None, univention.admin.mapping.ListToString)
+# fmt: on
 
 
 class object(univention.admin.handlers.simpleLdap):
@@ -149,7 +146,7 @@ class object(univention.admin.handlers.simpleLdap):
         return univention.admin.filter.conjunction('&', [
             univention.admin.filter.expression('objectClass', 'univentionSambaConfig'),
             univention.admin.filter.conjunction('!', [univention.admin.filter.expression('objectClass', 'univentionDomain')]),
-        ])
+        ])  # fmt: skip
 
 
 lookup = object.lookup
