@@ -1,7 +1,3 @@
-#
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
 # SPDX-FileCopyrightText: 2004-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
@@ -25,6 +21,7 @@ short_description = _('Settings: Syntax Definition')
 object_name = _('Syntax Definition')
 object_name_plural = _('Syntax Definitions')
 long_description = ''
+# fmt: off
 options = {
     'default': univention.admin.option(
         short_description=short_description,
@@ -121,6 +118,7 @@ mapping.register('base', 'univentionSyntaxLDAPBase', None, univention.admin.mapp
 mapping.register('viewonly', 'univentionSyntaxViewOnly', None, univention.admin.mapping.ListToString, encoding='ASCII')
 mapping.register('description', 'univentionSyntaxDescription', None, univention.admin.mapping.ListToString)
 mapping.register('addEmptyValue', 'univentionSyntaxAddEmptyValue', None, univention.admin.mapping.ListToString)
+# fmt: on
 
 
 class object(univention.admin.handlers.simpleLdap):
@@ -167,7 +165,7 @@ class object(univention.admin.handlers.simpleLdap):
     def _ldap_modlist(self):
         ml = univention.admin.handlers.simpleLdap._ldap_modlist(self)
 
-        attr = [val.encode('ASCII') for prop in ("attribute", "ldapattribute") for val in self[prop]]
+        attr = [val.encode('ASCII') for prop in ('attribute', 'ldapattribute') for val in self[prop]]
         ml.append(('univentionSyntaxLDAPAttribute', self.oldattr.get('univentionSyntaxLDAPAttribute', []), attr))
 
         val = self['ldapvalue'] or self['value']
