@@ -1,7 +1,3 @@
-#
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
 # SPDX-FileCopyrightText: 2013-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
@@ -29,6 +25,7 @@ short_description = _('Settings: UDM Syntax')
 object_name = _('UDM Syntax')
 object_name_plural = _('UDM Syntaxes')
 long_description = ''
+# fmt: off
 options = {
     'default': univention.admin.option(
         short_description=short_description,
@@ -131,6 +128,7 @@ mapping.register('package', 'univentionOwnedByPackage', None, univention.admin.m
 mapping.register('packageversion', 'univentionOwnedByPackageVersion', None, univention.admin.mapping.ListToString)
 mapping.register('ucsversionstart', 'univentionUCSVersionStart', None, univention.admin.mapping.ListToString)
 mapping.register('ucsversionend', 'univentionUCSVersionEnd', None, univention.admin.mapping.ListToString)
+# fmt: on
 # messagecatalog is handled via object._post_map and object._post_unmap defined below
 
 
@@ -149,8 +147,8 @@ class object(univention.admin.handlers.simpleLdap):
 
     def _post_unmap(self, info: univention.admin.handlers._Properties, values: univention.admin.handlers._Attributes) -> univention.admin.handlers._Properties:
         info['messagecatalog'] = []
-        messagecatalog_ldap_attribute = "univentionMessageCatalog"
-        messagecatalog_ldap_attribute_and_tag_prefix = "%s;entry-lang-" % (messagecatalog_ldap_attribute,)
+        messagecatalog_ldap_attribute = 'univentionMessageCatalog'
+        messagecatalog_ldap_attribute_and_tag_prefix = '%s;entry-lang-' % (messagecatalog_ldap_attribute,)
         for ldap_attribute, value_list in values.items():
             if ldap_attribute.startswith(messagecatalog_ldap_attribute_and_tag_prefix):
                 language_tag = ldap_attribute.split(messagecatalog_ldap_attribute_and_tag_prefix, 1)[1]
@@ -159,8 +157,8 @@ class object(univention.admin.handlers.simpleLdap):
         return info
 
     def _post_map(self, modlist, diff):
-        messagecatalog_ldap_attribute = "univentionMessageCatalog"
-        messagecatalog_ldap_attribute_and_tag_prefix = "%s;entry-lang-" % (messagecatalog_ldap_attribute,)
+        messagecatalog_ldap_attribute = 'univentionMessageCatalog'
+        messagecatalog_ldap_attribute_and_tag_prefix = '%s;entry-lang-' % (messagecatalog_ldap_attribute,)
         for property_name, old_value, new_value in diff:
             if property_name == 'messagecatalog':
                 old_dict = dict(old_value)
