@@ -1,7 +1,3 @@
-#
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
 # SPDX-FileCopyrightText: 2004-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
@@ -31,6 +27,7 @@ object_name = _('Password')
 object_name_plural = _('Passwords')
 long_description = ''
 options: dict[str, univention.admin.option] = {}
+# fmt: off
 property_descriptions = {
     'username': univention.admin.property(
         short_description=_('User name'),
@@ -54,10 +51,28 @@ layout = [
     Tab(_('Change password'), _('Change password'), [
         'password']),
 ]
+# fmt: on
 
 object = univention.admin.handlers.users.user.object
 
 
-def lookup(co: None, lo: univention.admin.uldap.access, filter_s: str, base: str = '', superordinate: univention.admin.handlers.simpleLdap | None = None, scope: str = 'sub', unique: bool = False, required: bool = False, timeout: int = -1, sizelimit: int = 0) -> list[univention.admin.handlers.simpleLdap]:
+def lookup(
+    co: None,
+    lo: univention.admin.uldap.access,
+    filter_s: str,
+    base: str = '',
+    superordinate: univention.admin.handlers.simpleLdap | None = None,
+    scope: str = 'sub',
+    unique: bool = False,
+    required: bool = False,
+    timeout: int = -1,
+    sizelimit: int = 0,
+) -> list[univention.admin.handlers.simpleLdap]:
     dn = lo.whoami()
-    return [user for user in univention.admin.handlers.users.user.lookup(co, lo, filter_s, base, superordinate, scope=scope, unique=unique, required=required, timeout=timeout, sizelimit=sizelimit) if lo.compare_dn(dn, user.dn)]
+    return [
+        user
+        for user in univention.admin.handlers.users.user.lookup(
+            co, lo, filter_s, base, superordinate, scope=scope, unique=unique, required=required, timeout=timeout, sizelimit=sizelimit,
+        )
+        if lo.compare_dn(dn, user.dn)
+    ]
